"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from daiedge_middleware_client.models.create_did_policy_body import CreateDIDPolicyBody
from daiedge_middleware_client.models.create_hardware_policy_body import CreateHardwarePolicyBody
from daiedge_middleware_client.models.edit_did_policy_body import EditDIDPolicyBody
from daiedge_middleware_client.models.edit_hardware_policy_body import EditHardwarePolicyBody
from daiedge_middleware_client.models.hardware_policy_response import HardwarePolicyResponse
from daiedge_middleware_client.models.remove_did_policy_body import RemoveDIDPolicyBody
from daiedge_middleware_client.models.remove_hardware_policy_body import RemoveHardwarePolicyBody

from daiedge_middleware_client.api_client import ApiClient, RequestSerialized
from daiedge_middleware_client.api_response import ApiResponse
from daiedge_middleware_client.rest import RESTResponseType


class PolicyApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def policies_dids_did_delete(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[RemoveDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_dids_did_delete

         Removes a DID policy for a user Binding: RemoveDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: RemoveDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_delete_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_dids_did_delete_with_http_info(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[RemoveDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_dids_did_delete

         Removes a DID policy for a user Binding: RemoveDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: RemoveDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_delete_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_dids_did_delete_without_preload_content(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[RemoveDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_dids_did_delete

         Removes a DID policy for a user Binding: RemoveDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: RemoveDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_delete_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_dids_did_delete_serialize(
        self,
        did,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if did is not None:
            _path_params['did'] = did
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/policies/dids/{did}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_dids_did_get(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        user_did: Annotated[Optional[StrictStr], Field(description="User DID who queries the data")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_dids_did_get

         Gets the DID policy for a user Binding: GetDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param user_did: User DID who queries the data
        :type user_did: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_get_serialize(
            did=did,
            user_did=user_did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_dids_did_get_with_http_info(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        user_did: Annotated[Optional[StrictStr], Field(description="User DID who queries the data")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_dids_did_get

         Gets the DID policy for a user Binding: GetDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param user_did: User DID who queries the data
        :type user_did: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_get_serialize(
            did=did,
            user_did=user_did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_dids_did_get_without_preload_content(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        user_did: Annotated[Optional[StrictStr], Field(description="User DID who queries the data")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_dids_did_get

         Gets the DID policy for a user Binding: GetDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param user_did: User DID who queries the data
        :type user_did: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_get_serialize(
            did=did,
            user_did=user_did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_dids_did_get_serialize(
        self,
        did,
        user_did,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if did is not None:
            _path_params['did'] = did
        # process the query parameters
        if user_did is not None:
            
            _query_params.append(('userDID', user_did))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/policies/dids/{did}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_dids_did_post(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[CreateDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_dids_did_post

         Creates a new DID policy for a user Binding: CreateDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: CreateDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_post_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_dids_did_post_with_http_info(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[CreateDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_dids_did_post

         Creates a new DID policy for a user Binding: CreateDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: CreateDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_post_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_dids_did_post_without_preload_content(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[CreateDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_dids_did_post

         Creates a new DID policy for a user Binding: CreateDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: CreateDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_post_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_dids_did_post_serialize(
        self,
        did,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if did is not None:
            _path_params['did'] = did
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/policies/dids/{did}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_dids_did_put(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[EditDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_dids_did_put

         Edits an existing DID policy for a user Binding: EditDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: EditDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_put_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_dids_did_put_with_http_info(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[EditDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_dids_did_put

         Edits an existing DID policy for a user Binding: EditDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: EditDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_put_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_dids_did_put_without_preload_content(
        self,
        did: Annotated[StrictStr, Field(description="Target DID")],
        request: Annotated[Optional[EditDIDPolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_dids_did_put

         Edits an existing DID policy for a user Binding: EditDIDPolicy

        :param did: Target DID (required)
        :type did: str
        :param request: Request body
        :type request: EditDIDPolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_dids_did_put_serialize(
            did=did,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_dids_did_put_serialize(
        self,
        did,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if did is not None:
            _path_params['did'] = did
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/policies/dids/{did}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_hardware_id_delete(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[RemoveHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_hardware_id_delete

         Removes hardware policy Binding: RemoveHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: RemoveHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_delete_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_hardware_id_delete_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[RemoveHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_hardware_id_delete

         Removes hardware policy Binding: RemoveHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: RemoveHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_delete_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_hardware_id_delete_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[RemoveHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_hardware_id_delete

         Removes hardware policy Binding: RemoveHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: RemoveHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_delete_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_hardware_id_delete_serialize(
        self,
        id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/policies/hardware/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_hardware_id_get(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> HardwarePolicyResponse:
        """policies_hardware_id_get

         Gets hardware policy Binding: GetHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "HardwarePolicyResponse",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_hardware_id_get_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[HardwarePolicyResponse]:
        """policies_hardware_id_get

         Gets hardware policy Binding: GetHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "HardwarePolicyResponse",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_hardware_id_get_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_hardware_id_get

         Gets hardware policy Binding: GetHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "HardwarePolicyResponse",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_hardware_id_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/policies/hardware/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_hardware_id_post(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[CreateHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_hardware_id_post

         Creates hardware policy Binding: CreateHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: CreateHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_hardware_id_post_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[CreateHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_hardware_id_post

         Creates hardware policy Binding: CreateHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: CreateHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_hardware_id_post_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[CreateHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_hardware_id_post

         Creates hardware policy Binding: CreateHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: CreateHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_hardware_id_post_serialize(
        self,
        id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/policies/hardware/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def policies_hardware_id_put(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[EditHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """policies_hardware_id_put

         Edits hardware policy Binding: EditHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: EditHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_put_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def policies_hardware_id_put_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[EditHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """policies_hardware_id_put

         Edits hardware policy Binding: EditHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: EditHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_put_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def policies_hardware_id_put_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Hardware ID")],
        request: Annotated[Optional[EditHardwarePolicyBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """policies_hardware_id_put

         Edits hardware policy Binding: EditHardwarePolicy

        :param id: Hardware ID (required)
        :type id: str
        :param request: Request body
        :type request: EditHardwarePolicyBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._policies_hardware_id_put_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _policies_hardware_id_put_serialize(
        self,
        id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/policies/hardware/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List
from daiedge_middleware_client.models.accelerator import Accelerator
from daiedge_middleware_client.models.cost import Cost
from daiedge_middleware_client.models.cpu import CPU
from daiedge_middleware_client.models.memory import Memory
from daiedge_middleware_client.models.power import Power
from daiedge_middleware_client.models.storage import Storage
from typing import Optional, Set
from typing_extensions import Self

class HardwareSpec(BaseModel):
    """
    HardwareSpec
    """ # noqa: E501
    cost: Cost
    cpus: List[CPU]
    accelerators: List[Accelerator]
    memory: Memory
    storage: Storage
    power: Power
    __properties: ClassVar[List[str]] = ["cost", "cpus", "accelerators", "memory", "storage", "power"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of HardwareSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of cost
        if self.cost:
            _dict['cost'] = self.cost.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in cpus (list)
        _items = []
        if self.cpus:
            for _item_cpus in self.cpus:
                if _item_cpus:
                    _items.append(_item_cpus.to_dict())
            _dict['cpus'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in accelerators (list)
        _items = []
        if self.accelerators:
            for _item_accelerators in self.accelerators:
                if _item_accelerators:
                    _items.append(_item_accelerators.to_dict())
            _dict['accelerators'] = _items
        # override the default output from pydantic by calling `to_dict()` of memory
        if self.memory:
            _dict['memory'] = self.memory.to_dict()
        # override the default output from pydantic by calling `to_dict()` of storage
        if self.storage:
            _dict['storage'] = self.storage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of power
        if self.power:
            _dict['power'] = self.power.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of HardwareSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cost": Cost.from_dict(obj["cost"]) if obj.get("cost") is not None else None,
            "cpus": [CPU.from_dict(_item) for _item in obj["cpus"]] if obj.get("cpus") is not None else None,
            "accelerators": [Accelerator.from_dict(_item) for _item in obj["accelerators"]] if obj.get("accelerators") is not None else None,
            "memory": Memory.from_dict(obj["memory"]) if obj.get("memory") is not None else None,
            "storage": Storage.from_dict(obj["storage"]) if obj.get("storage") is not None else None,
            "power": Power.from_dict(obj["power"]) if obj.get("power") is not None else None
        })
        return _obj





# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.register_hardware_list import RegisterHardwareList

class TestRegisterHardwareList(unittest.TestCase):
    """RegisterHardwareList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RegisterHardwareList:
        """Test RegisterHardwareList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RegisterHardwareList`
        """
        model = RegisterHardwareList()
        if include_optional:
            return RegisterHardwareList(
                hardware = [
                    daiedge_middleware_client.models.register_hardware_item.RegisterHardwareItem(
                        id = '', 
                        owner = '', 
                        created = 1.337, 
                        is_implemented = True, 
                        family = '', 
                        description = '', 
                        hardware_spec = daiedge_middleware_client.models.hardware_spec.HardwareSpec(
                            cost = daiedge_middleware_client.models.cost.Cost(
                                value = 1.337, 
                                currency = '', 
                                unit = '', ), 
                            cpus = [
                                daiedge_middleware_client.models.cpu.CPU(
                                    id = '', 
                                    arch = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        computing_power = , ), )
                                ], 
                            accelerators = [
                                daiedge_middleware_client.models.accelerator.Accelerator(
                                    id = '', 
                                    type = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = , 
                                        cores = , 
                                        computing_power = , ), )
                                ], 
                            memory = daiedge_middleware_client.models.memory.Memory(
                                type = '', 
                                kind = '', 
                                specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                                    size = , 
                                    rate = , ), ), 
                            storage = daiedge_middleware_client.models.storage.Storage(
                                type = '', 
                                specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                                    size = , 
                                    rate = , ), ), 
                            power = daiedge_middleware_client.models.power.Power(
                                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), 
                                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), ), ), 
                        software_spec = daiedge_middleware_client.models.software_spec.SoftwareSpec(
                            os = '', 
                            version = '', 
                            engines = [
                                daiedge_middleware_client.models.engine.Engine(
                                    id = '', 
                                    name = '', 
                                    family = '', 
                                    version = '', 
                                    computing_backends = [
                                        ''
                                        ], 
                                    supported_applications = [
                                        daiedge_middleware_client.models.supported_application.SupportedApplication(
                                            type = '', 
                                            details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                                supported_types = [
                                                    ''
                                                    ], ), )
                                        ], )
                                ], ), )
                    ],
                page = 1.337,
                total_pages = 1.337,
                total = 1.337
            )
        else:
            return RegisterHardwareList(
                hardware = [
                    daiedge_middleware_client.models.register_hardware_item.RegisterHardwareItem(
                        id = '', 
                        owner = '', 
                        created = 1.337, 
                        is_implemented = True, 
                        family = '', 
                        description = '', 
                        hardware_spec = daiedge_middleware_client.models.hardware_spec.HardwareSpec(
                            cost = daiedge_middleware_client.models.cost.Cost(
                                value = 1.337, 
                                currency = '', 
                                unit = '', ), 
                            cpus = [
                                daiedge_middleware_client.models.cpu.CPU(
                                    id = '', 
                                    arch = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        computing_power = , ), )
                                ], 
                            accelerators = [
                                daiedge_middleware_client.models.accelerator.Accelerator(
                                    id = '', 
                                    type = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = , 
                                        cores = , 
                                        computing_power = , ), )
                                ], 
                            memory = daiedge_middleware_client.models.memory.Memory(
                                type = '', 
                                kind = '', 
                                specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                                    size = , 
                                    rate = , ), ), 
                            storage = daiedge_middleware_client.models.storage.Storage(
                                type = '', 
                                specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                                    size = , 
                                    rate = , ), ), 
                            power = daiedge_middleware_client.models.power.Power(
                                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), 
                                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), ), ), 
                        software_spec = daiedge_middleware_client.models.software_spec.SoftwareSpec(
                            os = '', 
                            version = '', 
                            engines = [
                                daiedge_middleware_client.models.engine.Engine(
                                    id = '', 
                                    name = '', 
                                    family = '', 
                                    version = '', 
                                    computing_backends = [
                                        ''
                                        ], 
                                    supported_applications = [
                                        daiedge_middleware_client.models.supported_application.SupportedApplication(
                                            type = '', 
                                            details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                                supported_types = [
                                                    ''
                                                    ], ), )
                                        ], )
                                ], ), )
                    ],
        )
        """

    def testRegisterHardwareList(self):
        """Test RegisterHardwareList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Union
from daiedge_middleware_client.models.hardware_spec import HardwareSpec
from daiedge_middleware_client.models.software_spec import SoftwareSpec
from typing import Optional, Set
from typing_extensions import Self

class GetRegisterHardwareItem(BaseModel):
    """
    GetRegisterHardwareItem
    """ # noqa: E501
    owner: StrictStr = Field(description="Owner user DID")
    hash: StrictStr = Field(description="Register hardware hash")
    created: Union[StrictFloat, StrictInt] = Field(description="Creation timestamp")
    is_implemented: StrictBool = Field(description="Indicates if the hardware is implemented")
    family: StrictStr = Field(description="Hardware family or category (e.g., \"rpi4b\")")
    description: StrictStr = Field(description="Detailed description of the hardware (e.g., \"Raspberry Pi 4B with 4GB RAM\")")
    hardware_spec: HardwareSpec
    software_spec: SoftwareSpec
    __properties: ClassVar[List[str]] = ["owner", "hash", "created", "is_implemented", "family", "description", "hardware_spec", "software_spec"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetRegisterHardwareItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of hardware_spec
        if self.hardware_spec:
            _dict['hardware_spec'] = self.hardware_spec.to_dict()
        # override the default output from pydantic by calling `to_dict()` of software_spec
        if self.software_spec:
            _dict['software_spec'] = self.software_spec.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetRegisterHardwareItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "owner": obj.get("owner"),
            "hash": obj.get("hash"),
            "created": obj.get("created"),
            "is_implemented": obj.get("is_implemented"),
            "family": obj.get("family"),
            "description": obj.get("description"),
            "hardware_spec": HardwareSpec.from_dict(obj["hardware_spec"]) if obj.get("hardware_spec") is not None else None,
            "software_spec": SoftwareSpec.from_dict(obj["software_spec"]) if obj.get("software_spec") is not None else None
        })
        return _obj





# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.software_spec import SoftwareSpec

class TestSoftwareSpec(unittest.TestCase):
    """SoftwareSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SoftwareSpec:
        """Test SoftwareSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SoftwareSpec`
        """
        model = SoftwareSpec()
        if include_optional:
            return SoftwareSpec(
                os = '',
                version = '',
                engines = [
                    daiedge_middleware_client.models.engine.Engine(
                        id = '', 
                        name = '', 
                        family = '', 
                        version = '', 
                        computing_backends = [
                            ''
                            ], 
                        supported_applications = [
                            daiedge_middleware_client.models.supported_application.SupportedApplication(
                                type = '', 
                                details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                    supported_types = [
                                        ''
                                        ], ), )
                            ], )
                    ]
            )
        else:
            return SoftwareSpec(
                os = '',
                version = '',
                engines = [
                    daiedge_middleware_client.models.engine.Engine(
                        id = '', 
                        name = '', 
                        family = '', 
                        version = '', 
                        computing_backends = [
                            ''
                            ], 
                        supported_applications = [
                            daiedge_middleware_client.models.supported_application.SupportedApplication(
                                type = '', 
                                details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                    supported_types = [
                                        ''
                                        ], ), )
                            ], )
                    ],
        )
        """

    def testSoftwareSpec(self):
        """Test SoftwareSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.api.marketplace_api import MarketplaceApi


class TestMarketplaceApi(unittest.IsolatedAsyncioTestCase):
    """MarketplaceApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MarketplaceApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_marketplace_buy_post(self) -> None:
        """Test case for marketplace_buy_post

        """
        pass

    async def test_marketplace_delete(self) -> None:
        """Test case for marketplace_delete

        """
        pass

    async def test_marketplace_get(self) -> None:
        """Test case for marketplace_get

        """
        pass

    async def test_marketplace_sell_post(self) -> None:
        """Test case for marketplace_sell_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.power import Power

class TestPower(unittest.TestCase):
    """Power unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Power:
        """Test Power
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Power`
        """
        model = Power()
        if include_optional:
            return Power(
                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', ),
                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', )
            )
        else:
            return Power(
                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', ),
                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', ),
        )
        """

    def testPower(self):
        """Test Power"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.hardware_spec import HardwareSpec

class TestHardwareSpec(unittest.TestCase):
    """HardwareSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HardwareSpec:
        """Test HardwareSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HardwareSpec`
        """
        model = HardwareSpec()
        if include_optional:
            return HardwareSpec(
                cost = daiedge_middleware_client.models.cost.Cost(
                    value = 1.337, 
                    currency = '', 
                    unit = '', ),
                cpus = [
                    daiedge_middleware_client.models.cpu.CPU(
                        id = '', 
                        arch = '', 
                        model = '', 
                        specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                            rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            computing_power = , ), )
                    ],
                accelerators = [
                    daiedge_middleware_client.models.accelerator.Accelerator(
                        id = '', 
                        type = '', 
                        model = '', 
                        specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                            rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            computing_power = , ), )
                    ],
                memory = daiedge_middleware_client.models.memory.Memory(
                    type = '', 
                    kind = '', 
                    specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                        size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), 
                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), ), ),
                storage = daiedge_middleware_client.models.storage.Storage(
                    type = '', 
                    specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                        size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), 
                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), ), ),
                power = daiedge_middleware_client.models.power.Power(
                    min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                        value = 1.337, 
                        unit = '', ), 
                    max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                        value = 1.337, 
                        unit = '', ), )
            )
        else:
            return HardwareSpec(
                cost = daiedge_middleware_client.models.cost.Cost(
                    value = 1.337, 
                    currency = '', 
                    unit = '', ),
                cpus = [
                    daiedge_middleware_client.models.cpu.CPU(
                        id = '', 
                        arch = '', 
                        model = '', 
                        specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                            rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            computing_power = , ), )
                    ],
                accelerators = [
                    daiedge_middleware_client.models.accelerator.Accelerator(
                        id = '', 
                        type = '', 
                        model = '', 
                        specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                            rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                value = 1.337, 
                                unit = '', 
                                kind = '', ), 
                            computing_power = , ), )
                    ],
                memory = daiedge_middleware_client.models.memory.Memory(
                    type = '', 
                    kind = '', 
                    specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                        size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), 
                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), ), ),
                storage = daiedge_middleware_client.models.storage.Storage(
                    type = '', 
                    specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                        size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), 
                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                            value = 1.337, 
                            unit = '', 
                            kind = '', ), ), ),
                power = daiedge_middleware_client.models.power.Power(
                    min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                        value = 1.337, 
                        unit = '', ), 
                    max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                        value = 1.337, 
                        unit = '', ), ),
        )
        """

    def testHardwareSpec(self):
        """Test HardwareSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.storage_specs_item import StorageSpecsItem

class TestStorageSpecsItem(unittest.TestCase):
    """StorageSpecsItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StorageSpecsItem:
        """Test StorageSpecsItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StorageSpecsItem`
        """
        model = StorageSpecsItem()
        if include_optional:
            return StorageSpecsItem(
                size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', ),
                rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', )
            )
        else:
            return StorageSpecsItem(
                size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', ),
                rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', ),
        )
        """

    def testStorageSpecsItem(self):
        """Test StorageSpecsItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
